==> larus_board-1.1.0.zip: larus_board-1.1.0/setup/convert_phpbb2.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board".
 *
 * "Larus Board" is free software: you can redistribute it and/or modify
 * it under the terms of the modified BSD license.
 *
 * "Larus Board" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You should have received a copy of the modified BSD License
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.BSD>.
 */

  function xfs__info_phpbb2(){
  return array('id'=>'phpbb2','name'=>'phpBB','supported_versions'=>'2.0.x','url'=>'http://www.phpbb.com/','guest'=>'-1','active'=>true);
  }

  function xfs__convert_phpbb2(){
  // TODO: [low] xfs__convert() fix some minor bugs, what about transferring ratings/votes?
    function xfs_es($a){return utf8_encode(preg_replace('|[\\\]+(["\']{1})|','\1',$a));}
    function xfs_stbl($a){return $_POST['dbs_name'].'.'.$_POST['dbs_prefix'].$a;}
  $dbsrc = ( $_POST['dbs_type'] === 'mysql' )
  ? new PDO('mysql:host='.$_POST['dbs_host'].';dbname='.$_POST['dbs_name'],$_POST['dbs_username'],$_POST['dbs_password'])
  : new PDO('pgsql:dbname='.$_POST['dbs_name'].';user='.$_POST['dbs_username'].';password='.$_POST['dbs_password'],null,null);
  XF::sql_query("TRUNCATE ".XF::tbl('post_data'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('post_meta'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('post_rating'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('tag_data'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('tag_meta'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('user'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('user_blacklist'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('user_bookmark'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('user_request'),'',__METHOD__,__LINE__);
  $DATA_tag = array('');
  $DATA_tag_map = array();
  $DATA_statistic = array();
  $DATA_statistic_map = array();
  $T = array();
  $skip = array();
  $prevent = array();
  $Smax = 0;
  $i = 0;

  $Sstat = XF::sql_query("SELECT st_day,st_month,st_year FROM ".XF::tbl('statistic'));
    while ( $Rstat = $Sstat->fetchObject() ){
    $Rstat->st_day = intval($Rstat->st_day);
    $Rstat->st_month = intval($Rstat->st_month);
    $Rstat->st_year = intval($Rstat->st_year);
      if ( !isset($DATA_statistic_map[$Rstat->st_year]) )
      $DATA_statistic_map[$Rstat->st_year] = array();
      if ( !isset($DATA_statistic_map[$Rstat->st_year][$Rstat->st_month]) )
      $DATA_statistic_map[$Rstat->st_year][$Rstat->st_month] = array();
      if ( !isset($DATA_statistic_map[$Rstat->st_year][$Rstat->st_month][$Rstat->st_day]) )
      $DATA_statistic_map[$Rstat->st_year][$Rstat->st_month][$Rstat->st_day] = true;
    }
  $Sstat->closeCursor();

  $Spost = $dbsrc->query("SELECT COUNT(post_id) AS post_id FROM ".xfs_stbl('posts_text'));
  $tmp = $Spost->fetchObject();
  $Spost->closeCursor();
  $Suser = $dbsrc->query("SELECT user_id,user_active,username,user_password,user_lastvisit,user_regdate,
  user_level,user_posts,user_email FROM ".xfs_stbl('users'));
  $Smax = (int)$tmp->post_id+$Suser->rowCount(); unset($tmp);
    while ( $Ruser = $Suser->fetchObject() ){
    $Ruser->user_id = intval($Ruser->user_id);
    $T['regdate'] = implode('_',array(gmdate('Y',$Ruser->user_regdate),gmdate('m',$Ruser->user_regdate),gmdate('d',$Ruser->user_regdate)));
    $T['regdate_day'] = gmdate('d',$Ruser->user_regdate);
    $T['regdate_month'] = gmdate('m',$Ruser->user_regdate);
    $T['regdate_year'] = gmdate('Y',$Ruser->user_regdate);
      if ( $Ruser->user_id === (int)$_POST['guest_uid'] )
      $Ruser->user_id = 1;
    $ug = ( (int)$Ruser->user_level === 1 ) ? 4 : 2;
      if ( $Ruser->user_id === 1 ){
      XF::sql_query("UPDATE ".XF::tbl('config')." SET c_value = :data WHERE c_id = 'main_guest_uid'",array('data'=>array($Ruser->user_id,'int')),__METHOD__,__LINE__);
      $Ruser->username = '{:guest}';
      $Ruser->user_email = '';
      $Ruser->user_active = 0;
      $ug = 1;
      }
      if ( !isset($DATA_statistic[$T['regdate']]) )
      $DATA_statistic[$T['regdate']] = array('u'=>0,'p'=>0);
    $DATA_statistic[$T['regdate']]['u']++;
    XF::sql_query("INSERT INTO ".XF::tbl('user')." (u_id,u_name,u_password,u_mail,u_group,u_time_registration,u_time_last_read,u_post_count,u_active,u_login_count)
      VALUES (:id,:name,:password,:mail,:group,:regtime,:lastread,:posts,:active,:logincount)",array(
    'id'=>array($Ruser->user_id,'int'),
    'name'=>array(xfs_es($Ruser->username),'str'),
    'password'=>array('','str'),
    'mail'=>array(xfs_es($Ruser->user_email),'str'),
    'group'=>array($ug,'int'),
    'regtime'=>array($Ruser->user_regdate,'int'),
    'lastread'=>array($Ruser->user_lastvisit,'int'),
    'posts'=>array($Ruser->user_posts,'int'),
    'active'=>array($Ruser->user_active,'str'),
    'logincount'=>array(1,'int')),__METHOD__,__LINE__);
    $i++;
      if ( $i%50 === 0 )
      xfs__progressbar(round(($i/$Smax)*100,0));
    }
  $Suser->closeCursor();

    for ( $a = 1 ; $a <= 2 ; $a++ ){
      if ( $a === 1 )
      $Spost = $dbsrc->query("SELECT topic_id AS post_id,topic_id,topic_poster AS poster_id,topic_time AS post_time,topic_status,topic_type,post_subject,post_text FROM ".xfs_stbl('topics')."
      LEFT JOIN ".xfs_stbl('posts_text')." ON ".xfs_stbl('posts_text').".post_id = ".xfs_stbl('topics').".topic_id");
      elseif ( $a === 2 )
      $Spost = $dbsrc->query("SELECT ".xfs_stbl('posts').".post_id,topic_id,poster_id,post_time,post_subject,post_text FROM ".xfs_stbl('posts')."
      LEFT JOIN ".xfs_stbl('posts_text')." ON ".xfs_stbl('posts_text').".post_id = ".xfs_stbl('posts').".post_id");

      while ( $Rpost = $Spost->fetchObject() ){
      $Rpost->post_id = intval($Rpost->post_id);
      $Rpost->topic_id = intval($Rpost->topic_id);
      $Rpost->poster_id = intval($Rpost->poster_id);
      $Rpost->post_time = intval($Rpost->post_time);
        if ( $a === 1 )
        $skip[] = $Rpost->post_id;
        elseif ( $a === 2 && in_array($Rpost->post_id,$skip,true) )
        continue;
      $T['is_topic'] = ( $a === 1 ) ? '1' : '0';
      $T['closed'] = ( isset($Rpost->topic_status) && (int)$Rpost->topic_status === 1 ) ? '1' : '0';
      $T['weight'] = ( isset($Rpost->topic_type) ) ? (int)$Rpost->topic_type : '0';
      $T['postdate'] = implode('_',array(gmdate('Y',$Rpost->post_time),gmdate('m',$Rpost->post_time),gmdate('d',$Rpost->post_time)));
      $T['ss'] = explode(' ',$Rpost->post_subject);
        if ( !isset($DATA_statistic[$T['postdate']]) )
        $DATA_statistic[$T['postdate']] = array('u'=>0,'p'=>0);
      $DATA_statistic[$T['postdate']]['p']++;

        foreach ( $T['ss'] as $v ){
        $v = preg_replace('/[^a-z0-9]+/i','',strtolower($v));
          if ( is_numeric($v) || strlen($v) < 4 ) continue;
          if ( !isset($DATA_tag_map[$v]) ){
          $DATA_tag[] = $v;
          $DATA_tag_map[$v] = sizeof($DATA_tag)-1;
          XF::sql_query("INSERT INTO ".XF::tbl('tag_meta')." (t_id,t_name) VALUES
          ('".intval($DATA_tag_map[$v])."',".XF::$sql->quote(xfs_es($v)).")",'',__METHOD__,__LINE__);
          }
          if ( !isset($prevent[$Rpost->post_id]) )
          $prevent[$Rpost->post_id] = array();
          if ( !in_array($DATA_tag_map[$v],$prevent[$Rpost->post_id]) ){
          $prevent[$Rpost->post_id][] = $DATA_tag_map[$v];
          XF::sql_query("INSERT INTO ".XF::tbl('tag_data')." (td_t_id,td_p_id) VALUES
          ('".intval($DATA_tag_map[$v])."','".$Rpost->post_id."')",'',__METHOD__,__LINE__);
          }
        }

      XF::sql_query("INSERT INTO ".XF::tbl('post_meta')." (p_id,p_is_topic,p_topic_id,p_pd_id,p_u_id,p_time,p_weight,p_rating,p_approved,p_closed,p_subject)
      VALUES (:id,:istopic,:topicid,:postmsgid,:userid,:time,:weight,:rating,:approve,:close,:subject)",array(
      'id'=>array($Rpost->post_id,'int'),
      'istopic'=>array($T['is_topic'],'str'),
      'topicid'=>array($Rpost->topic_id,'int'),
      'postmsgid'=>array($Rpost->post_id,'int'),
      'userid'=>array($Rpost->poster_id,'int'),
      'time'=>array($Rpost->post_time,'int'),
      'weight'=>array($T['weight'],'int'),
      'rating'=>array(0,'int'),
      'approve'=>array('1','str'),
      'close'=>array($T['closed'],'str'),
      'subject'=>array(xfs_es($Rpost->post_subject),'str')),__METHOD__,__LINE__);
      XF::sql_query("INSERT INTO ".XF::tbl('post_data')." (pd_id,pd_p_id,pd_time,pd_text)
      VALUES (:id,:postid,:time,:message)",array(
      'id'=>array($Rpost->post_id,'int'),
      'postid'=>array($Rpost->topic_id,'int'),
      'time'=>array($Rpost->post_time,'int'),
      'message'=>array(xfs_es($Rpost->post_text),'str')),__METHOD__,__LINE__);
      $i++;
        if ( $i%50 === 0 )
        xfs__progressbar(round(($i/$Smax)*100,0));
      }

    $Spost->closeCursor();
    }

    foreach ( $DATA_statistic as $k=>$v ){
    $k = explode('_',$k);
      if ( !isset($DATA_statistic_map[(int)$k[0]][(int)$k[1]][(int)$k[2]]) ){
      XF::sql_query("INSERT INTO ".XF::tbl('statistic')." (st_day,st_month,st_year) VALUES (:day,:month,:year)",array(
      'day'=>array($k[2],'int'),
      'month'=>array($k[1],'int'),
      'year'=>array($k[0],'int')),__METHOD__,__LINE__);
      }
    XF::sql_query("UPDATE ".XF::tbl('statistic')." SET
    st_account_register = :acr, st_account_activation = :aca, st_submit_posting = :sup
    WHERE st_day = :day AND st_month = :month AND st_year = :year",array(
    'acr'=>array($v['u'],'int'),
    'aca'=>array($v['u'],'int'),
    'sup'=>array($v['p'],'int'),
    'day'=>array($k[2],'int'),
    'month'=>array($k[1],'int'),
    'year'=>array($k[0],'int')),__METHOD__,__LINE__);
    }

  $dbsrc = null;
  }

?>

==> larus_board-1.1.2.zip: larus_board-1.1.2/setup/convert_phpbb2.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009,2010 by "The Larus Board Team"
 * This file is part of "Larus Board".
 *
 * "Larus Board" is free software: you can redistribute it and/or modify
 * it under the terms of the modified BSD license.
 *
 * "Larus Board" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You should have received a copy of the modified BSD License
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.BSD>.
 */

  function xfs__info_phpbb2(){
  return array('id'=>'phpbb2','name'=>'phpBB','supported_versions'=>'2.0.x','url'=>'http://www.phpbb.com/','guest'=>'-1','active'=>true);
  }

  function xfs__convert_phpbb2(){
  // TODO: [low] xfs__convert() fix some minor bugs, what about transferring ratings/votes?
    function xfs_es($a){return utf8_encode(preg_replace('|[\\\]+(["\']{1})|','\1',$a));}
    function xfs_stbl($a){return $_POST['dbs_name'].'.'.$_POST['dbs_prefix'].$a;}
  $dbsrc = ( $_POST['dbs_type'] === 'mysql' )
  ? new PDO('mysql:host='.$_POST['dbs_host'].';dbname='.$_POST['dbs_name'],$_POST['dbs_username'],$_POST['dbs_password'])
  : new PDO('pgsql:dbname='.$_POST['dbs_name'].';user='.$_POST['dbs_username'].';password='.$_POST['dbs_password'],null,null);
  XF::sql_query("TRUNCATE ".XF::tbl('post_data'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('post_meta'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('post_rating'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('tag_data'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('tag_meta'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('user'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('user_blacklist'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('user_bookmark'),'',__METHOD__,__LINE__);
  XF::sql_query("TRUNCATE ".XF::tbl('user_request'),'',__METHOD__,__LINE__);
  $DATA_tag = array('');
  $DATA_tag_map = array();
  $DATA_statistic = array();
  $DATA_statistic_map = array();
  $T = array();
  $skip = array();
  $prevent = array();
  $Smax = 0;
  $i = 0;

  $Sstat = XF::sql_query("SELECT st_day,st_month,st_year FROM ".XF::tbl('statistic'));
    while ( $Rstat = $Sstat->fetchObject() ){
    $Rstat->st_day = intval($Rstat->st_day);
    $Rstat->st_month = intval($Rstat->st_month);
    $Rstat->st_year = intval($Rstat->st_year);
      if ( !isset($DATA_statistic_map[$Rstat->st_year]) )
      $DATA_statistic_map[$Rstat->st_year] = array();
      if ( !isset($DATA_statistic_map[$Rstat->st_year][$Rstat->st_month]) )
      $DATA_statistic_map[$Rstat->st_year][$Rstat->st_month] = array();
      if ( !isset($DATA_statistic_map[$Rstat->st_year][$Rstat->st_month][$Rstat->st_day]) )
      $DATA_statistic_map[$Rstat->st_year][$Rstat->st_month][$Rstat->st_day] = true;
    }
  $Sstat->closeCursor();

  $Spost = $dbsrc->query("SELECT COUNT(post_id) AS post_id FROM ".xfs_stbl('posts_text'));
  $tmp = $Spost->fetchObject();
  $Spost->closeCursor();
  $Suser = $dbsrc->query("SELECT user_id,user_active,username,user_password,user_lastvisit,user_regdate,
  user_level,user_posts,user_email FROM ".xfs_stbl('users'));
  $Smax = (int)$tmp->post_id+$Suser->rowCount(); unset($tmp);
    while ( $Ruser = $Suser->fetchObject() ){
    $Ruser->user_id = intval($Ruser->user_id);
    $T['regdate'] = implode('_',array(gmdate('Y',$Ruser->user_regdate),gmdate('m',$Ruser->user_regdate),gmdate('d',$Ruser->user_regdate)));
    $T['regdate_day'] = gmdate('d',$Ruser->user_regdate);
    $T['regdate_month'] = gmdate('m',$Ruser->user_regdate);
    $T['regdate_year'] = gmdate('Y',$Ruser->user_regdate);
      if ( $Ruser->user_id === (int)$_POST['guest_uid'] )
      $Ruser->user_id = 1;
    $ug = ( (int)$Ruser->user_level === 1 ) ? 4 : 2;
      if ( $Ruser->user_id === 1 ){
      XF::sql_query("UPDATE ".XF::tbl('config')." SET c_value = :data WHERE c_id = 'main_guest_uid'",array('data'=>array($Ruser->user_id,'int')),__METHOD__,__LINE__);
      $Ruser->username = '{:guest}';
      $Ruser->user_email = '';
      $Ruser->user_active = 0;
      $ug = 1;
      }
      if ( !isset($DATA_statistic[$T['regdate']]) )
      $DATA_statistic[$T['regdate']] = array('u'=>0,'p'=>0);
    $DATA_statistic[$T['regdate']]['u']++;
    XF::sql_query("INSERT INTO ".XF::tbl('user')." (u_id,u_uuid,u_name,u_password,u_mail,u_group,u_time_registration,u_time_last_read,u_post_count,u_active,u_login_count)
    VALUES (:id,:uuid,:name,:password,:mail,:group,:regtime,:lastread,:posts,:active,:logincount)",array(
    'id'=>array($Ruser->user_id,'int'),
    'uuid'=>array(XF::uuid(),'str'),
    'name'=>array(xfs_es($Ruser->username),'str'),
    'password'=>array('','str'),
    'mail'=>array(xfs_es($Ruser->user_email),'str'),
    'group'=>array($ug,'int'),
    'regtime'=>array($Ruser->user_regdate,'int'),
    'lastread'=>array($Ruser->user_lastvisit,'int'),
    'posts'=>array($Ruser->user_posts,'int'),
    'active'=>array($Ruser->user_active,'str'),
    'logincount'=>array(1,'int')),__METHOD__,__LINE__);
    $i++;
      if ( $i%50 === 0 )
      xfs__progressbar(round(($i/$Smax)*100,0));
    }
  $Suser->closeCursor();

    for ( $a = 1 ; $a <= 2 ; $a++ ){
      if ( $a === 1 )
      $Spost = $dbsrc->query("SELECT topic_id AS post_id,topic_id,topic_poster AS poster_id,topic_time AS post_time,topic_status,topic_type,post_subject,post_text FROM ".xfs_stbl('topics')."
      LEFT JOIN ".xfs_stbl('posts_text')." ON ".xfs_stbl('posts_text').".post_id = ".xfs_stbl('topics').".topic_id");
      elseif ( $a === 2 )
      $Spost = $dbsrc->query("SELECT ".xfs_stbl('posts').".post_id,topic_id,poster_id,post_time,post_subject,post_text FROM ".xfs_stbl('posts')."
      LEFT JOIN ".xfs_stbl('posts_text')." ON ".xfs_stbl('posts_text').".post_id = ".xfs_stbl('posts').".post_id");

      while ( $Rpost = $Spost->fetchObject() ){
      $Rpost->post_id = intval($Rpost->post_id);
      $Rpost->topic_id = intval($Rpost->topic_id);
      $Rpost->poster_id = intval($Rpost->poster_id);
      $Rpost->post_time = intval($Rpost->post_time);
        if ( $a === 1 )
        $skip[] = $Rpost->post_id;
        elseif ( $a === 2 && in_array($Rpost->post_id,$skip,true) )
        continue;
      $T['is_topic'] = ( $a === 1 ) ? '1' : '0';
      $T['closed'] = ( isset($Rpost->topic_status) && (int)$Rpost->topic_status === 1 ) ? '1' : '0';
      $T['weight'] = ( isset($Rpost->topic_type) ) ? (int)$Rpost->topic_type : '0';
      $T['postdate'] = implode('_',array(gmdate('Y',$Rpost->post_time),gmdate('m',$Rpost->post_time),gmdate('d',$Rpost->post_time)));
      $T['ss'] = explode(' ',$Rpost->post_subject);
        if ( !isset($DATA_statistic[$T['postdate']]) )
        $DATA_statistic[$T['postdate']] = array('u'=>0,'p'=>0);
      $DATA_statistic[$T['postdate']]['p']++;

        foreach ( $T['ss'] as $v ){
        $v = preg_replace('/[^a-z0-9]+/i','',strtolower($v));
          if ( is_numeric($v) || strlen($v) < 4 ) continue;
          if ( !isset($DATA_tag_map[$v]) ){
          $DATA_tag[] = $v;
          $DATA_tag_map[$v] = sizeof($DATA_tag)-1;
          XF::sql_query("INSERT INTO ".XF::tbl('tag_meta')." (t_id,t_name) VALUES
          ('".intval($DATA_tag_map[$v])."',".XF::$sql->quote(xfs_es($v)).")",'',__METHOD__,__LINE__);
          }
          if ( !isset($prevent[$Rpost->post_id]) )
          $prevent[$Rpost->post_id] = array();
          if ( !in_array($DATA_tag_map[$v],$prevent[$Rpost->post_id]) ){
          $prevent[$Rpost->post_id][] = $DATA_tag_map[$v];
          XF::sql_query("INSERT INTO ".XF::tbl('tag_data')." (td_t_id,td_p_id) VALUES
          ('".intval($DATA_tag_map[$v])."','".$Rpost->post_id."')",'',__METHOD__,__LINE__);
          }
        }

      XF::sql_query("INSERT INTO ".XF::tbl('post_meta')." (p_id,p_is_topic,p_topic_id,p_parent_id,p_pd_id,p_u_id,p_time,p_weight,p_rating,p_approved,p_closed,p_subject)
      VALUES (:id,:istopic,:topicid,:parentid,:postmsgid,:userid,:time,:weight,:rating,:approve,:close,:subject)",array(
      'id'=>array($Rpost->post_id,'int'),
      'istopic'=>array($T['is_topic'],'str'),
      'topicid'=>array($Rpost->topic_id,'int'),
      'parentid'=>array($Rpost->topic_id,'int'),
      'postmsgid'=>array($Rpost->post_id,'int'),
      'userid'=>array($Rpost->poster_id,'int'),
      'time'=>array($Rpost->post_time,'int'),
      'weight'=>array($T['weight'],'int'),
      'rating'=>array(0,'int'),
      'approve'=>array('1','str'),
      'close'=>array($T['closed'],'str'),
      'subject'=>array(xfs_es($Rpost->post_subject),'str')),__METHOD__,__LINE__);
      XF::sql_query("INSERT INTO ".XF::tbl('post_data')." (pd_id,pd_p_id,pd_time,pd_text)
      VALUES (:id,:postid,:time,:message)",array(
      'id'=>array($Rpost->post_id,'int'),
      'postid'=>array($Rpost->topic_id,'int'),
      'time'=>array($Rpost->post_time,'int'),
      'message'=>array(xfs_es($Rpost->post_text),'str')),__METHOD__,__LINE__);
      $i++;
        if ( $i%50 === 0 )
        xfs__progressbar(round(($i/$Smax)*100,0));
      }

    $Spost->closeCursor();
    }

    foreach ( $DATA_statistic as $k=>$v ){
    $k = explode('_',$k);
      if ( !isset($DATA_statistic_map[(int)$k[0]][(int)$k[1]][(int)$k[2]]) ){
      XF::sql_query("INSERT INTO ".XF::tbl('statistic')." (st_day,st_month,st_year) VALUES (:day,:month,:year)",array(
      'day'=>array($k[2],'int'),
      'month'=>array($k[1],'int'),
      'year'=>array($k[0],'int')),__METHOD__,__LINE__);
      }
    XF::sql_query("UPDATE ".XF::tbl('statistic')." SET
    st_account_register = :acr, st_account_activation = :aca, st_submit_posting = :sup
    WHERE st_day = :day AND st_month = :month AND st_year = :year",array(
    'acr'=>array($v['u'],'int'),
    'aca'=>array($v['u'],'int'),
    'sup'=>array($v['p'],'int'),
    'day'=>array($k[2],'int'),
    'month'=>array($k[1],'int'),
    'year'=>array($k[0],'int')),__METHOD__,__LINE__);
    }

  $dbsrc = null;
  }

?>
